extensions [
  gis
  profiler
  Rnd
  table
  array
]

globals [
  vegetation                 ; input data of vegetation types for each patch
  time_vt                    ; time spent in veg type (cumulative for all foragers each day)
  tide                       ; keeps track of the tide; can be "poor" (most often), "OK" (8 days/month), or "good" (2 days/month)
  cum_kcal                   ; total kcal accumulated throughout simulation
  cum_km
  days-until-tide            ; days until next good tidal cycle
  tideday                    ; ranges from 0-14 over the tidal cycle, last 5 are springdays
  kcal_vt1
  kcal_vt2                   ; globals to keep track of kcal foraged in each vt
  kcal_vt3
  kcal_vt4
  kcal_vt5
  kcal_vt6
  kcal_vt8
  kcal_vt9
  kcal_vt10
  kcal_vt11
  kcal_vt12
  kcal_vt13
  kcal_vt14
  patches-vt
  patches-vt10
  patches-coast
  mean_dailykcal
  mean_dailykm
  time-walk-cell
  camp-mobility
  listspecies
  camp_size                   ; average camp size in number of foragers (H+G)

  ;reporter variables
  coastdist_avg               ; reports avg camp coast distance
  kcal_avg_perstep            ; keeps track of avg kcal per time_interval
  coastdist_avg_perstep       ; keeps track of avg camp coast distance per time_interval
  dailykm_avg_perstep         ; keeps track of avg daily km per time_interval
  marine_kcal

  ;hunting
  success-rate              ; list of success rates for each species (doesn't vary per habitat)
  success-rate-sd           ; corresponding standard deviations of success rates
  pursuit-time              ; list of pursuit times for each species (in hours)
  pursuit-time-sd           ; corresponding standard deviations of pursuit times
  prey_cal                  ; caloric return for each species, replaces weight
  prey_cal_stdev            ; stdev of caloric return for each species, to introduce variance in returns and better accord to input data
  nrspecies                 ; number of prey species
  rt-rate                   ; return rate for each species
  hunt-time                 ; time spend hunting different species
  meat_vt                   ; for each vegetation type the kcal of animals caught
  hunters gathers           ; agentsets to hold each agent type. (like breed but more flexible)
  memoryfood                ; number of days the camps use to evaluate whether productivity of camp is sufficient to stay

  ;;PROJECTILE DISCARD ADDITION
  archeo-patch              ; patchset of patches with at least one armature
  site-patches              ; patchset of patches where at least one camp settled at some point
  file                      ; name of the file for outputs
  endgame                   ; to deal with low populations. Triggered when a camp does not have hunters
  habitat-hit-table         ; table that records the probabilities of damaging an armature in each environment
  point-table               ; table that records the item position of different keys
]

patches-own [
  vt                        ; vegetation/coastal resource type
  kcal_return               ; original kcal/hr return rate for each patch  (includes coastal cell spring tide returns)
  kcal_return_min           ; same for terrestrial, but holds lower value for non-spring and non-low tides of coastal patches
  stdev_kcal_return         ; for giving variable returns based on mean/stdev inputs
  current_kcal_return       ; current kcal/hr return rate for each patch, under systematic-search-of-habitat assumption, is either vt-specific full or zero
  total-harvest-time        ; search/harvest time (hr/ha)           Varies from 0.63-17.9 hr/hectare. 17.9 is 3 or 4 forager days worth of harvesting...
  pass-harvest-time         ; search/harvest time (hr/ha) to cross a patch once. Always total-time-harvest/5 since foragers cover a 20m wide swath of the 1ha cell
  goodcoast?                ; boolean to exclude Sandy Beach from coastal foraging patches   ;should replace with a goodcoast patch-set
  time-until-replenished    ; veg replenishes after 365 days, counter gets reset to zero after each instance of harvesting (no half-patches replenishing at separtate times)
  kcal-gathered             ; fix of times-gathered which had problems with neap harvests
  times-camped              ; counter for times a camp has stayed on each patch
  temporal_multiplier       ; strange piece of code to weigh the returns over the next days_of_foresight
  mult-undepl
  mult-repl
  mult-depl

  ;hunting vars, start the listyness
  encounter                 ; encounter rates, probability of encountering one of mammal list in N encounters / 100 m
  counted                   ; counter for the number of species checked in a patch during encounter procedure
  timelast                  ; time since a given camp last visited a patch, works like a memory to keep them from walking back to same area over and over
  hunt_kcal_return          ; average return for patches due to habitat type, used in mobility decisions against travel time, foresight, etc.
  hunt_temporal_multiplier  ; Not used currently, but would be the hunting equivalent of the temporal_multiplier in gathering.
  probnoencounter           ; the probability that a forager does not encounter a species
  time-until-mammal         ; specific mammal's encounter rate drops to zero after kill (following Ache model) for X days

  ;;PROJECTILE DISCARD ADDITION
  site?                     ; true if a camp settled on the patch at some point
  assemblage                ; records the list of all armatures discarded on the patch
  total-kcal-shell          ; records the amount of shell consumed at camp on that patch
  total-kcal-shell-process  ; records the amount of shell processed on site
  total-kcal-shell-temp     ; records the amount of shell consumed at camp on that patch
  total-kcal-plant          ; records the amount of plant consumed at camp on that patch
  total-kcal-meat           ; records the amount of meat consumed at camp on that patch
  previous-vt               ; records the vt where a camp was previously (too look at mobility)
  dist-coast                ; records the distance from the nearest coast
]
breed [foragers forager]    ;

breed [camps camp]
foragers-own [
  time-forage-budget        ; time a forager has left to forage
  time-foraged              ; time forager has foraged
  dailykcal                 ; total kcal foraged each day (updated throughout the day, cleared at end of day)
  dailykcal_shell           ; total marine kcal
  dailykcal_plant           ; total plant kcal
  dailykcal_hunt            ; total mammal hunting kcal
  done                      ; done for the day
  timecamp                  ; travel time between forager and camp
  dailykm
  campsite                  ; camp of the forager
  days_without1500          ; individual counter for days below a certain threshold of calories, currently 1500
  days_without3000          ; individual counter for days below a certain threshold of calories, currently 3000 (reflecting a forager and a dependent)

  ;hunting vars
  hg                        ; hunter or gatherer switch, val=h or val=g
  avgpastrr                 ; average return rates over last x days
  potmeat                   ; amount of meat (in kcal) caught during a pursuit
  pursuit                   ; boolean whether forager is in pursuit
  time-pursuit              ; time an forager was in a pursuit

  ;;PROJECTILE DISCARD ADDITION
  projectile                ; values of the projectile armature
  body-part                 ; identifies the body part hit by the projectile armature

  ;; Coastal addition
  onsiteProcessing?         ; identifies if the shellfish were processed on site or at the camp

]
camps-own [
  directions                ; list of directions of initial movements at the start of the day
  directioncamp             ; direction to which camp will move
  leftorright               ; randomly defined boolean whether foragers go initially left or right to the camp at the start of the day
  kcal_per_day              ; total kcal accumulated each day
  hist_kcal_per_day         ; list of total kcal accumulated for the last x days
  kcal_total                ; total kcal accumulated throughout entire scenario
  overall_avg_kcal          ; rolling mean kcal per forager per day over memoryfood days
  timecoast                 ; camps track their distance to the coast, for use in mod-cog scenario
  coastal_target            ; the closest coastal patch to camp at any given time
  days_without1500          ; counter of days the camp brings in below a threshold of calories / forager, currently 1500
  days_without3000          ; counter of days the camp brings in below a threshold of calories / forager, currently 3000 (forager and dependent)
  times_moved               ; counter of frequency of camp movement, to be divided by ticks
  km_moved                  ; counter of total kms moved, to get an average distance of moves
  my_camp_size              ; camps' individual size since this varies a bit per camp depending on population rounding

  ;; Coastal addition
  this-vt                   ; the vegetation at the location where the camp stands
  ]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;Brief species list based on interglacial conditions without the Agulhas plain
;Species_ID Species
;0	Bushbuck
;1	Bushpig
;2	Grey Duiker
;3	Grysbok
;4	Rock hyrax
;5  Eland

to setup
  ca
  reset-ticks

  ;; SEED FOR TESTING
  ;random-seed 1

  ;;*****SET UP REPORTERS*****
  set kcal_avg_perstep 0
  set coastdist_avg_perstep 0
  set dailykm_avg_perstep 0
  set coastdist_avg 0
  set marine_kcal 0

  ;;*****SET UP VEGETATION*****
  ifelse map-zone = "z1" OR map-zone = "z2" [
      set vegetation gis:load-dataset (word "../data/allhab_1ha_" map-zone ".asc")
      resize-world 0 299 0 199 set-patch-size 1.75
  ]
  [ ; full size
      set vegetation gis:load-dataset "../data/all_habitats_1ha.asc"
      resize-world 0 779 0 539 set-patch-size 0.65
  ]

  gis:set-world-envelope gis:envelope-of vegetation
  ;;  apply GIS data to vet types
  gis:apply-raster vegetation vt

  ask patches [ set vt ifelse-value ( vt <= 0 ) or ( vt > 0 ) [ vt ][ 0 ]]
  set patches-vt (patch-set patches with [vt > 0])
  set patches-coast (patch-set patches with [vt >= 10])

  set patches-vt10 (patch-set patches with [vt > 0 and vt < 10])

  ;; assign veg types initial kcal/hr return rates and harvest times ;probably worth using CSV:from-file from-row for this
  ask patches-vt [                                                       ; as of 09/18/2018 pulled from a new R script using Sue's 20180803_CAL.FOREVENT.csv data file. This is only Summer, the rest is controlled by plant-cycle

    if vt = 1  [set total-harvest-time 1.54   set kcal_return 270]       ; Freshwater wetlands / Riparian
    if vt = 2  [set total-harvest-time 2.18   set kcal_return 179]       ; Alluvial Vegetation
    if vt = 3  [set total-harvest-time 0.62   set kcal_return 219]       ; Strandveld
    if vt = 4  [set total-harvest-time 0.00   set kcal_return 0]         ; Saline Vegetation
    if vt = 5  [set total-harvest-time 1.51   set kcal_return 63]        ; Renosterveld
    if vt = 6  [set total-harvest-time 1.88   set kcal_return 354]       ; Sand Fynbos
    if vt = 8  [set total-harvest-time 0.58   set kcal_return 241]       ; Thicket
    if vt = 9  [set total-harvest-time 1.60   set kcal_return 130]       ; Limestone Fynbos

    ;shellfishing rates updated 2017 summer using raw means from 2013-2014 field seasons
    if vt = 10 [set total-harvest-time 1.5   set kcal_return 2019   set kcal_return_min 250]      ; Aeolianite (Coastal); the coastal rates here are "poor", the most common state
    if vt = 11 [set total-harvest-time 1.5   set kcal_return 87]                                  ; Sandy Beach (Coastal); only coastal vt with a fixed return
    if vt = 12 [set total-harvest-time 1.5   set kcal_return 1799   set kcal_return_min 250]      ; TMS Boulders (Coastal)
    if vt = 13 [set total-harvest-time 1.5   set kcal_return 1203   set kcal_return_min 250]      ; TMS Eroded Rocky Headlands (Coastal)
    if vt = 14 [set total-harvest-time 1.5   set kcal_return 1867   set kcal_return_min 250]      ; TMS Wave Cut Platforms (Coastal)

    ;test version with bumped coastal harvest rates
    ;if vt >= 10 [set kcal_return 2500]

    ifelse vt < 10 [set pass-harvest-time total-harvest-time / 5][set pass-harvest-time total-harvest-time / 3] ;5 passes needed for terrestrial, 3 passes needed for coastal (3 people deplete in 30 minutes)
    if kcal_return_min = 0 [set kcal_return_min kcal_return]         ; clone the reg return value for terrestrial patches for pick-patch-

    ;hunting vars for terrestrials - copied from Mammal Abundance Data - Paleoscape Model

    if vt = 1 [ set encounter (list
        0.00003636	0.00004444	0.00004444	0.00000000	0.00000000
        )]
    if vt = 2 [ set encounter (list
        0.00003636	0.00005128	0.00000000	0.00000000	0.00000000
        )]
    if vt = 3 [ set encounter (list
        0.00000400	0.00002667	0.00006667	0.00000781	0.00000000
        )]
    if vt = 4 [ set encounter (list
        0.00000000	0.00000000	0.00000000	0.00000000	0.00000000
        )]
    if vt = 5 [ set encounter (list
        0.00000400	0.00002667	0.00005714	0.00008696	0.00000000
        )]
    if vt = 6 [ set encounter (list
        0.00000355	0.00002667	0.00006250	0.00009524	0.00000000
        )]
    if vt = 8 [ set encounter (list
        0.00005714	0.00005128	0.00008333	0.00012500	0.00000000
        )]
    if vt = 9 [ set encounter (list
        0.00000294	0.00002667	0.00006061	0.00009091	0.00000000
        )]
    if vt >= 10 AND vt != 11 [ set encounter (list
        0.00000000	0.00000000	0.00000000	0.00000000	0.00100000
        )] ;this is Rocky coast values for hyrax etc. appropriate habitats?
    if vt = 11 [ set encounter (list
       0 0 0 0 0 ;0
      )]

    let i 0
    set timelast []
    while [i < nrcamps]
    [
       set timelast lput (- 100) timelast
       set i i + 1
    ]
    set time-until-mammal (list 0 0 0 0 0 );0)

    set times-camped 0
  ]

  ask patches-coast [
    set mult-undepl (list kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return kcal_return kcal_return kcal_return kcal_return kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return kcal_return kcal_return kcal_return kcal_return) ; looped over two cycles to account for long temporal foresight range
    set mult-repl (list 0 0 0 0 0 0 0 0 0 0 kcal_return kcal_return kcal_return kcal_return kcal_return kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return kcal_return kcal_return kcal_return kcal_return)
    set mult-depl (list 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return_min kcal_return kcal_return kcal_return kcal_return kcal_return)
  ]

  set nrspecies 5
  set listspecies []
  let j 0
  while [j < nrspecies]  ; define list of species
  [
    set listspecies lput j listspecies
    set j j + 1
  ]
  set memoryfood 7

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;PROJECTILE DISCARD ADDITION ;;
  set endgame false  ; by default, this is false. Will become true if a camp does not have hunters
  ;; Using a table to deal with individual vegetations' probability of hitting each plant type.
  ;; Values from Cowling and De Vynck pers. comm.
  ;; The values are cumulative probabilities, so if a random value is above the first, it may be between the first prob and the second, and so on...
  set habitat-hit-table table:make
  table:put habitat-hit-table "key" (list "tree" "bush" "grass" "reed")  ;; For easier visualization of which values are what
  table:put habitat-hit-table 1 (list 0 0.3 0.6 1)                       ;; Freshwater wetlands (vt1) probabilities of hitting tree, bush, grass, or reeds
  table:put habitat-hit-table 2 (list 0.5 0.65 0.9 1)                    ;; Floodplain Woodland (Alluvial) (vt2) probabilities of hitting tree, bush, grass, or reeds
  table:put habitat-hit-table 3 (list 0.1 0.9 1 0)                       ;; Strandveld (vt3) probabilities of hitting tree, bush, grass, or reeds
  table:put habitat-hit-table 4 (list 0 1 0 0)                           ;; Saline vegetation (vt4) probabilities of hitting tree, bush, grass, or reeds
  table:put habitat-hit-table 5 (list 0 0.8 1 0)                         ;; Renosterveld (vt5) probabilities of hitting tree, bush, grass, or reeds
  table:put habitat-hit-table 6 (list 0 0.95 1 0)                        ;; Sand Fynbos (vt6) probabilities of hitting tree, bush, grass, or reeds
  table:put habitat-hit-table 8 (list 0.5 0.95 1 0)                      ;; Albany Thicket (vt8) probabilities of hitting tree, bush, grass, or reeds
  table:put habitat-hit-table 9 (list 0 0.95 1 0)                        ;; Limestone Fynbos (vt9) probabilities of hitting tree, bush, grass, or reeds
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ask patches [

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;; VARIANTS ADDITION
    ;; Create the empty bin for artifacts assemblage.
    set assemblage []
    ;; create empty lists for food brought back to camp
    set total-kcal-shell []
    set total-kcal-shell-temp []
    set total-kcal-shell-process []
    set total-kcal-plant []
    set total-kcal-meat []
    ;; create empty list that will record previous vt of camps
    set previous-vt []
    ;set dist-coast distance min-one-of patches with [vt = 0] [distance myself] ; Very computation intensive
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    ;; set up goodcoast?
    set goodcoast? false
    if (vt = 10 OR vt > 11)   ; sand (11) is bad coast!
      [set goodcoast? true]
  ]

  ;;*****SET UP CAMPS*****

  create-camps nrcamps
  [
    move-to one-of patches-vt
    set shape "house"
    set color red
    set size 5
    set hidden? false
    set hist_kcal_per_day (list 2000 2000 2000 2000 2000 2000 2000)
    let whichcamp who
    ask patches in-radius 10 [
      if vt > 0 [ set timelast replace-item whichcamp timelast 0]]
    ;ask patch-here [ set site? site? + 1 ]
    set this-vt vt ; records the vegetation of the current patch
  ]

  ;;*****SET UP forager-GATHERERS*****
  create-foragers round (nrforagers * (1 - hunter-percent))                        ;shifting to this method so that we can divide the same number of foragers into variable group sizes
  [
    set color red
    set hg "g"
    set shape "person"
    set size 2
    set time-forage-budget daily-time-budget
    set dailykcal 0
    set dailykm 0
    set hidden? true
    set campsite min-one-of camps [count foragers-here ] move-to campsite

  ]

  ;;*****SET UP forager-HUNTERS*****

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;; PROJECTILE DISCARD ADDITION ;;
  ;; Create the master table of the projectile's array items
  create-point-table
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  create-foragers round (nrforagers * hunter-percent)                        ;shifting to this method so that we can divide the same number of foragers into variable group sizes
  [
    set color blue
    set hg "h"
    set shape "person"
    set size 2
    set time-forage-budget daily-time-budget
    set dailykcal 0
    set dailykm 0
    set hidden? true

    set campsite min-one-of camps [count foragers-here with [hg = "h"]] move-to campsite

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;; VARIANTS ADDITION
    ;; To create the stone tools
    create-new-point                                    ;; This creates an array of 6 values (4 0s and 2 false)
    set onsiteProcessing? false                         ;; for the Coastal paper
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ]

  ;for now setup hunters and gatherers, this might not work in future for task-switching. Or alternatively will need to be updated later.
  set hunters foragers with [hg = "h"]
  set gathers foragers with [hg = "g"]
  set camp_size nrforagers / nrcamps
  ask camps [ set my_camp_size count foragers with [campsite = myself]]

  ;;*****SET UP OTHER INITIALIZATION PARAMETERS*****
  set cum_kcal 0
  set time-walk-cell 1 / walk-speed / 10                              ;flip walk-speed to hours / hectare so 2 km/h = .05 hours / hectare
  set camp-mobility daily-time-budget * walk-speed * 10 * 0.75        ;need to set a good value so that foragers have time to harvest during the day. this was the purpose of the campless experiments but i'm not sure we came to a good answer.
  ask patches-vt [set current_kcal_return kcal_return_min]
  ask camps [ set overall_avg_kcal 0
    set kcal_total 0
    set kcal_per_day 0
  set coastal_target 0
  ]

  ask patches-vt
  [
    let temp (list)
    let i 1
    repeat days_of_foresight [set temp lput (current_kcal_return / (1 + discount_rate * i)) temp set i i + 1]        ; weaker net present value rate 1/(1+r*t), hyperbolic
    set temporal_multiplier sum temp                                          ;this value is the temporally weighted return in calories for one hour a day of x days_of_foresight. Essentially a kcal/hr with foresighted days weighed in. Multiply it against daily-time-budget for total kcal harvest over those days, sorta...
  ]

  ; global hunting var
  set rt-rate (list 0 0 0 0 0 0) ;0)
  set hunt-time (list 0 0 0 0 0 ) ;0)
  set prey_cal (list 163800	170625	14430	7800	7800 )
  set pursuit-time (list 0.603 1.820 0.106 0.032 0.220 )
  set pursuit-time-sd (list 0.298 3.388 0.053 0.007 0.085 )
  set success-rate (list 0.070 0.100 0.500 0.042 0.220 )
  set success-rate-sd (list 0.26 0.32 0.5 0.203 0.41 )

  let k 0
  while [k < nrspecies]
  [
     set rt-rate replace-item k rt-rate ((item k success-rate * item k prey_cal) / item k pursuit-time )
     set k k + 1
  ]

  let probnoencounter1 1 let rt-rate1 0
  ask one-of patches with [vt = 1] [
    let ii 0
    while [ii < nrspecies]
    [
      set probnoencounter1 probnoencounter1 * (1 - item ii encounter)
      set rt-rate1 rt-rate1 + (item ii rt-rate * item ii encounter)
      set ii ii + 1
    ]
  ]
  let probnoencounter2 1 let rt-rate2 0
  if any? patches with [vt = 2] [ask one-of patches with [vt = 2] [let ii 0 while [ii < nrspecies][ set probnoencounter2 probnoencounter2 * (1 - item ii encounter) set rt-rate2 rt-rate2 + (item ii rt-rate * item ii encounter) set ii ii + 1]]]
  let probnoencounter3 1 let rt-rate3 0
  ask up-to-n-of 1 patches with [vt = 3] [let ii 0 while [ii < nrspecies][ set probnoencounter3 probnoencounter3 * (1 - item ii encounter) set rt-rate3 rt-rate3 + (item ii rt-rate * item ii encounter) set ii ii + 1]]
  let probnoencounter4 1 let rt-rate4 0
  if any? patches with [vt = 4] [ask one-of patches with [vt = 4] [let ii 0 while [ii < nrspecies][ set probnoencounter4 probnoencounter4 * (1 - item ii encounter) set rt-rate4 rt-rate4 + (item ii rt-rate * item ii encounter)  set ii ii + 1]]]
  let probnoencounter5 1 let rt-rate5 0
  ask up-to-n-of 1 patches with [vt = 5] [let ii 0 while [ii < nrspecies][ set probnoencounter5 probnoencounter5 * (1 - item ii encounter) set rt-rate5 rt-rate5 + (item ii rt-rate * item ii encounter)  set ii ii + 1]]
  let probnoencounter6 1 let rt-rate6 0
  ask up-to-n-of 1 patches with [vt = 6] [let ii 0 while [ii < nrspecies][ set probnoencounter6 probnoencounter6 * (1 - item ii encounter) set rt-rate6 rt-rate6 + (item ii rt-rate * item ii encounter)  set ii ii + 1]]
  let probnoencounter8 1 let rt-rate8 0
  ask up-to-n-of 1 patches with [vt = 8] [let ii 0 while [ii < nrspecies][ set probnoencounter8 probnoencounter8 * (1 - item ii encounter) set rt-rate8 rt-rate8 + (item ii rt-rate * item ii encounter)  set ii ii + 1]]
  let probnoencounter9 1 let rt-rate9 0
  ask up-to-n-of 1 patches with [vt = 9] [let ii 0 while [ii < nrspecies][ set probnoencounter9 probnoencounter9 * (1 - item ii encounter) set rt-rate9 rt-rate9 + (item ii rt-rate * item ii encounter)  set ii ii + 1]]
  let probnoencounter10 1 let rt-rate10 0
  ask up-to-n-of 1 patches with [vt = 10] [let ii 0 while [ii < nrspecies][ set probnoencounter10 probnoencounter10 * (1 - item ii encounter) set rt-rate10 rt-rate10 + (item ii rt-rate * item ii encounter)  set ii ii + 1]]
  let probnoencounter11 1  let rt-rate11 0
  ask up-to-n-of 1 patches with [vt = 11] [let ii 0 while [ii < nrspecies][ set probnoencounter11 probnoencounter11 * (1 - item ii encounter) set rt-rate11 rt-rate11 + (item ii rt-rate * item ii encounter)  set ii ii + 1]]
  let probnoencounter12 1  let rt-rate12 0
  ask up-to-n-of 1 patches with [vt = 12] [let ii 0 while [ii < nrspecies][ set probnoencounter12 probnoencounter12 * (1 - item ii encounter) set rt-rate12 rt-rate12 + (item ii rt-rate * item ii encounter)  set ii ii + 1]]
  let probnoencounter13 1 let rt-rate13 0
  ask up-to-n-of 1 patches with [vt = 13] [let ii 0 while [ii < nrspecies][ set probnoencounter13 probnoencounter13 * (1 - item ii encounter) set rt-rate13 rt-rate13 + (item ii rt-rate * item ii encounter)  set ii ii + 1]]
  let probnoencounter14 1 let rt-rate14 0
  ask up-to-n-of 1 patches with [vt = 14] [let ii 0 while [ii < nrspecies][ set probnoencounter14 probnoencounter14 * (1 - item ii encounter) set rt-rate14 rt-rate14 + (item ii rt-rate * item ii encounter)  set ii ii + 1]]
  ask patches-vt [
    if vt = 1 [set probnoencounter probnoencounter1 set hunt_kcal_return round rt-rate1]
    if vt = 2 [set probnoencounter probnoencounter2 set hunt_kcal_return round rt-rate2]
    if vt = 3 [set probnoencounter probnoencounter3 set hunt_kcal_return round rt-rate3]
    if vt = 4 [set probnoencounter probnoencounter4 set hunt_kcal_return round rt-rate4]
    if vt = 5 [set probnoencounter probnoencounter5 set hunt_kcal_return round rt-rate5]
    if vt = 6 [set probnoencounter probnoencounter6 set hunt_kcal_return round rt-rate6]
    if vt = 8 [set probnoencounter probnoencounter8 set hunt_kcal_return round rt-rate8]
    if vt = 9 [set probnoencounter probnoencounter9 set hunt_kcal_return round rt-rate9]
    if vt = 10 [set probnoencounter probnoencounter10 set hunt_kcal_return round rt-rate10]
    if vt = 11 [set probnoencounter probnoencounter11 set hunt_kcal_return round rt-rate11]
    if vt = 12 [set probnoencounter probnoencounter12 set hunt_kcal_return round rt-rate12]
    if vt = 13 [set probnoencounter probnoencounter13 set hunt_kcal_return round rt-rate13]
    if vt = 14 [set probnoencounter probnoencounter14 set hunt_kcal_return round rt-rate14]
  ]
  ask patches-vt
  [
    let temp (list)
    let i 1
    repeat days_of_foresight [set temp lput (hunt_kcal_return / (1 + discount_rate * i)) temp set i i + 1]
    set hunt_temporal_multiplier sum temp          ;this means that we can multiply this against foraging_budget to get days_of_foresight worth of expected & discounted hunting returns
  ]

  set meat_vt (list 0 0 0 0 0 0 0 0 0 0 0 0)

  set kcal_vt1 0
  set kcal_vt2 0
  set kcal_vt3 0
  set kcal_vt4 0
  set kcal_vt5 0
  set kcal_vt6 0
  set kcal_vt8 0
  set kcal_vt9 0
  set kcal_vt10 0
  set kcal_vt11 0
  set kcal_vt12 0
  set kcal_vt13 0
  set kcal_vt14 0

  ;; display map
  ask patches with [vt = 0] [set pcolor blue]
  run (word "display-" display-mode)

  ;;;;;;;;;;;;;;;;;;
  ;;     ADDITION ;;
  ;; This file collects the artifact values at the end of the simulation
  if outputs? = true
  [ set file ( word "../Outputs_" map-zone "_" nrcamps "_" daily-time-budget "_" spatial-foresight "_" random-float 1 ".csv" )        ;; Creates a unique name for the file (Important when using BehaviorSpace)
    if file-exists? file                                     ;; Will overwrite similar files, which is why the random-float is so important.
    [ file-delete file ]
    file-open file
    file-print (sentence ",bs.run.number,n.camps,spatial.foresight,daily.time.budget,hunter.percent,vision.forager,forager.movement,n.foragers,days.foresight,global.knowledge,walk.speed,xcor,ycor,site,length.assemblage,vegetation,mean.kcal,totalKcalShell,totalKcalShellProcess,totalKcalPlant,totalKcalMeat,previousVt,onsiteProcessThreshold,ticks,")       ;; Values recorded by the model (where and what)
    file-close ]
  ;;;;;;;;;;;;;;;;;;

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  tick ;print (word ticks " and still going strong")
  tidal-cycle
  plant-cycle
  update-patches

  run (word "display-" display-mode)

  update-campsites
  ifelse (count patches with [current_kcal_return > 0] != 0) [
    if count gathers > 0 [gather]
    if count hunters > 0 [hunt]
  ][if outputs? = true
    [ export-values ]
  print "ran out of food" stop ]

  update-camp-numbers    ;moved to procedure for speed testing

  ;;;;;;;;;;;;;;;;;;;;;;
  ;; VARIANTS ADDITION
  if ticks > max-tick or endgame   ; If the tick maximum has been reached or if one camp does not have any hunter (which would create an error), the simulation stops.
  [ if outputs?
    [ export-values ]
    print "reached the max tick" stop ]
  ;;;;;;;;;;;;;;;;;;;;;;

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update-reporters
  set coastdist_avg mean [distance min-one-of patches with [goodcoast? = true] [distance myself]] of camps

  set kcal_avg_perstep kcal_avg_perstep + kcal-avg
  set coastdist_avg_perstep coastdist_avg_perstep + coastdist_avg
  set dailykm_avg_perstep dailykm_avg_perstep + mean [dailykm] of foragers

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update-patches

set archeo-patch patches with [ assemblage != []]
set site-patches patches with [ site? > 0 ]

ask patches-vt
[
  if vt < 10 and time-until-replenished > 0 [set time-until-replenished time-until-replenished - 1]
  if sum time-until-mammal > 0 [
      ;set time-until-mammal time-until-mammal - 1
      let i 0
      while [i < nrspecies] [
        if item i time-until-mammal > 0 [set time-until-mammal replace-item i time-until-mammal (item i time-until-mammal - 1)]
        set i i + 1
      ]
    ]
  if vt >= 10 [set time-until-replenished days-until-tide]
  if time-until-replenished = 0
  [
    set current_kcal_return kcal_return
    ifelse vt < 10 [set total-harvest-time pass-harvest-time * 5][set total-harvest-time pass-harvest-time * 3]
  ]
]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to tidal-cycle

  ;; days 1-10 = poor, 11-15 = good, repeat.
  ;0: poor
  ;1: poor
  ;2: poor
  ;3: poor
  ;4: poor
  ;5: poor
  ;6: poor
  ;7: poor
  ;8: poor
  ;9: poor
  ;10: OK
  ;11: OK
  ;12: good       ; enough variation in time of year, weather, swell, that this evens out and doesn't make a difference
  ;13: OK
  ;14: OK
  set tideday remainder ticks 15

  ;; kcal returns for each tidal state
  if tideday = 0 [
    ask patches-coast [if current_kcal_return > kcal_return_min [set current_kcal_return kcal_return_min]]
  ]
  if tideday = 10 [
    ask patches-coast [set current_kcal_return kcal_return]
  ]
  set days-until-tide 10 - tideday ; there are 10 poor days in between tidal cycles

  ask patches-coast
  [
    ;init with undepleted case
    let mult mult-undepl ;; this is related to temporal foresight, ie. anticipating returns over several days in advance. This makes the travel cost less of a big deal since you walk once then harvest 5 days
                         ;; the discount rate is because food now is worth relatively more than the same food several days from now. It is designed to be multiplied against kcal/hr later on in the pick-patch-X
    if current_kcal_return = 0
      [
        ifelse tideday < 10 [set mult mult-repl] ; case of tide being replenished at next spring
        [set mult mult-depl]  ; case of tide being replenished to low at next non-spring
      ]
    let i 1
    set temporal_multiplier 0
    while [i <= days_of_foresight]
    [
      set temporal_multiplier temporal_multiplier + (1 / (1 + discount_rate * i)) * item (tideday + i) mult ; hyperbolic
      set i i + 1
    ]
  ]

end

to plant-cycle                ;seasonal differences harvesting 20180803 data table from Susan
  ask patches-vt10 [
    ifelse remainder ticks 365 = 0  [ ;Summer
      if vt = 1  [set total-harvest-time 1.54   set kcal_return 270]      ; Freshwater wetlands / Riparian
      if vt = 2  [set total-harvest-time 2.18   set kcal_return 179]      ; Alluvial Vegetation
      if vt = 3  [set total-harvest-time 0.62   set kcal_return 219]       ; Strandveld
      if vt = 4  [set total-harvest-time 0.00   set kcal_return 0]      ; Saline Vegetation
      if vt = 5  [set total-harvest-time 1.51   set kcal_return 63]      ; Renosterveld
      if vt = 6  [set total-harvest-time 1.88   set kcal_return 354]      ; Sand Fynbos
      if vt = 8  [set total-harvest-time 0.58   set kcal_return 241]      ; Thicket
      if vt = 9  [set total-harvest-time 1.60   set kcal_return 130]     ; Limestone Fynbos
      set pass-harvest-time total-harvest-time / 5
      set current_kcal_return kcal_return
      set time-until-replenished 0
    ]
    [
      ifelse remainder ticks 365 = 92  [ ;Autumn
        if vt = 1  [set total-harvest-time 1.47   set kcal_return 223]      ; Freshwater wetlands / Riparian
        if vt = 2  [set total-harvest-time 2.95   set kcal_return 240]      ; Alluvial Vegetation
        if vt = 3  [set total-harvest-time 1.26   set kcal_return 231]       ; Strandveld
        if vt = 4  [set total-harvest-time 0.00   set kcal_return 0]      ; Saline Vegetation
        if vt = 5  [set total-harvest-time 3.92   set kcal_return 139]      ; Renosterveld
        if vt = 6  [set total-harvest-time 1.36   set kcal_return 518]      ; Sand Fynbos
        if vt = 8  [set total-harvest-time 0.70   set kcal_return 176]      ; Thicket
        if vt = 9  [set total-harvest-time 0.82   set kcal_return 116]     ; Limestone Fynbos
        set pass-harvest-time total-harvest-time / 5
        set current_kcal_return kcal_return
        set time-until-replenished 0
      ][
        ifelse remainder ticks 365 = 183  [ ;Winter
          if vt = 1  [set total-harvest-time 1.22   set kcal_return 164]      ; Freshwater wetlands / Riparian
          if vt = 2  [set total-harvest-time 3.58   set kcal_return 122]      ; Alluvial Vegetation
          if vt = 3  [set total-harvest-time 1.20   set kcal_return 211]       ; Strandveld
          if vt = 4  [set total-harvest-time 0.00   set kcal_return 0]      ; Saline Vegetation
          if vt = 5  [set total-harvest-time 1.81   set kcal_return 126]      ; Renosterveld
          if vt = 6  [set total-harvest-time 2.54   set kcal_return 370]      ; Sand Fynbos
          if vt = 8  [set total-harvest-time 0.44   set kcal_return 66]      ; Thicket
          if vt = 9  [set total-harvest-time 1.79   set kcal_return 141]     ; Limestone Fynbos
          set pass-harvest-time total-harvest-time / 5
          set current_kcal_return kcal_return
          set time-until-replenished 0
        ][  ;Spring
          if remainder ticks 365 = 273 [
            if vt = 1  [set total-harvest-time 1.47   set kcal_return 233]      ; Freshwater wetlands / Riparian
            if vt = 2  [set total-harvest-time 0.97   set kcal_return 240]      ; Alluvial Vegetation
            if vt = 3  [set total-harvest-time 0.67   set kcal_return 248]       ; Strandveld
            if vt = 4  [set total-harvest-time 0.00   set kcal_return 0]      ; Saline Vegetation
            if vt = 5  [set total-harvest-time 1.78   set kcal_return 80]      ; Renosterveld
            if vt = 6  [set total-harvest-time 2.13   set kcal_return 481]      ; Sand Fynbos
            if vt = 8  [set total-harvest-time 2.24   set kcal_return 62]      ; Thicket
            if vt = 9  [set total-harvest-time 1.30   set kcal_return 109]     ; Limestone Fynbos
            set pass-harvest-time total-harvest-time / 5
            set current_kcal_return kcal_return
            set time-until-replenished 0
          ]
        ]
      ]
    ]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to update-campsites
  ask camps [
    ask patches in-radius 10 [if vt > 0 [set timelast replace-item [who] of myself timelast ticks]]      ;10 cell radius fairly arbitrary, it equals 1km at hectare scale, but hunters go much farther
    set kcal_per_day 0
    if overall_avg_kcal < camp-move-threshold
    [
      ifelse spatial-foresight = true [
        spatial-foresight-movement          ;mod to be hunter or gatherer-driven
      ]
      [
        let p one-of patches in-radius camp-mobility with [vt > 0]
        set times_moved times_moved + 1
        set km_moved km_moved + (distance p / 10)
        move-to p

      ] ; close spatial-foresight else
      set hist_kcal_per_day []   ;this resets after a move so the 7 day list is only at new camp location

      ;;;;;;;;;;;;;;;;;;;;;;;
      ;; VARIANTS ADDITION
      ask patch-here [
        set site? site? + 1 ; when a site lands on a patch, that patch's site? variable adds 1
        set previous-vt lput [ this-vt ] of myself previous-vt  ; adds the vegetation of the camp's previous patch to the list
      ]
      ;;;;;;;;;;;;;;;;;;;;;;;
    ]

    set times-camped times-camped + 1
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to spatial-foresight-movement          ;called by camps in update-campsites
  let best_pot_camp patch 0 0
  ifelse global-knowledge? [
    ifelse mobility = "hunter-driven"
    [
      set best_pot_camp pick-patch-hunt-foresight
    ]
    [ ;else "gatherer-driven"
      set best_pot_camp pick-patch-global-tidal-foresight
    ]
  ][
    ifelse mobility = "hunter-driven"
    [
      set best_pot_camp pick-patch-hunt
    ]
    [
      set best_pot_camp pick-patch-local-tidal-foresight
    ]
  ]
  ifelse [current_kcal_return] of best_pot_camp = 0 OR count other camps-on best_pot_camp > 0
    [
      set times_moved times_moved + 1
      set km_moved km_moved + walk-speed
      move-to max-one-of patches-at-radius (walk-speed * 10) [current_kcal_return] ;move to a cell one hour walk away
    ]
    [ ;else target good so move to/towards
      let p_d distance best_pot_camp
      ifelse p_d <= camp-mobility       ;within movement range?
      [
        set times_moved times_moved + 1
        set km_moved km_moved + (p_d / 10)
        move-to best_pot_camp

      ]
      [ ;else move towards location
        face best_pot_camp
        ifelse [vt] of patch-ahead camp-mobility > 0
        [
          set times_moved times_moved + 1
          set km_moved km_moved + camp-mobility
          move-to patch-ahead camp-mobility
        ]
        [ ;else there's ocean in the way so jump as far as you can to a habitable cell
          set times_moved times_moved + 1
          set km_moved km_moved + (camp-mobility / 10)
          move-to max-one-of patches-at-radius camp-mobility [current_kcal_return]          ; maybe an odd fix, but it works and is uncommon anyway. places camps randomly along an camp-mobility distant arc
        ]
      ]
    ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to gather
  ;;*****INITIALIZE A NEW DAY*****
  ask gathers [
    set dailykcal 0
    set dailykcal_shell 0
    set dailykcal_plant 0
    set dailykm 0
    set time-forage-budget daily-time-budget
    set done 0
   ]

  ;; *****ACTUAL FORAGING (INCLUDING KEEPING TRACK OF TIME AND DISTANCE TO CAMP)*****
  let allgathersdone 0
  while [allgathersdone = 0] ;all forager movement happens within a tick, works but hard to eval since you can't see inside the loop very well
    [
      ask gathers with [done = 0][
        ;set timecamp distance campsite * [pass-harvest-time] of patch-here         ; expected time (in minutes) for an forager to walk back to the camp harvesting along the way
        set timecamp distance campsite * time-walk-cell                             ; expected time (in minutes) for an forager to walk straight back to the camp without harvesting
        ifelse time-forage-budget > timecamp                                       ; true if time budget is less than the time it takes to cross a cell (aka time to go home)
          [ ; time left for foraging
            ; so forager moves to forage
            ; in this version, foragers move on if the current_kcal_return of the patch they are on drops below the average for the patches they could potentially move to
            ; whether they move to the best patch in this radius is determined by the switch "forager-movement"; code is under "move" process
            move-gather     ;jan16 foragers pick a distant cell but then harvest towards it so never reach. issue bc timecamp is based on harvesting on the way home.
          ]
          [ ;else no extra foraging time left, "forage on the way home"
            face campsite
            let found 0
            ifelse [vt] of patch-ahead 1 > 0
            [
              move-to patch-ahead 1 set found 1
            ]
            [
              while [found = 0]
              [
                if patch-ahead 1 != nobody [
                  if [vt] of patch-ahead 1 > 0 [move-to patch-ahead 1 set found 1]
                ]
                if found = 0 [rt random 45 lt random 45]
              ]
            ] ;close else patch-ahead
            set time-forage-budget time-forage-budget - time-walk-cell
            set dailykm dailykm + .1
          ] ; close else time left
        set timecamp distance campsite * time-walk-cell
        if (distance campsite < 1.5 AND time-forage-budget < time-walk-cell) OR dailykcal > max_kcal_to_harvest OR time-forage-budget < 0 [      ;next to or at campsite and foraging time has run out OR have enough kcal
          let d distance campsite
          move-to campsite ;teleports foragers home if they've harvested enough
          set dailykm dailykm + d
          set done 1 ;   show time-forage-budget ; they're consistently over-shooting their foraging budget since they check time against current patch, then move to a patch w/ different harvest time
        ]
      ] ;close ask gathers

      if sum [done] of gathers = count gathers [
        set allgathersdone 1
        ask gathers with [dailykcal < 3000]
        [
          set days_without3000 days_without3000 + 1
          if dailykcal < 1500 [set days_without1500 days_without1500 + 1]
        ]
        ask camps [
          set kcal_per_day kcal_per_day + sum [dailykcal] of gathers with [campsite = myself]
          ;; ADDED record the amount of plant collected
          set total-kcal-plant lput precision ( sum [dailykcal_plant] of gathers with [campsite = myself]) 2 total-kcal-plant
          set total-kcal-shell lput ( sum total-kcal-shell-temp ) total-kcal-shell ; calculates the sum of shellfish consumed here
          set total-kcal-shell-temp [] ; resets
          set previous-vt lput this-vt previous-vt  ; adds the vegetation of the camp's previous patch to the list
          set this-vt vt  ; update the vt-here with the current patch's vt
        ]
      ]
    ]  ;close while
end

to hunt
    ;;*****INITIALIZE A NEW DAY*****
  ask hunters [
    set dailykcal 0
    set dailykcal_hunt 0
    set dailykm 0
    set time-forage-budget daily-time-budget
    set done 0
   ]
  ;; *****ACTUAL HUNTING (INCLUDING KEEPING TRACK OF TIME AND DISTANCE TO CAMP)*****
  let allhuntersdone 0
    if forager-movement = "local-patch-choice"
  [
    ask camps [
      let my-hunters hunters with [campsite = myself]
      ifelse not any? my-hunters [ set endgame True ] ;;****    Added this because small camps without hunters create error.
      [ ask one-of hunters with [campsite = myself][
        face pick-patch-huntstep
        ask hunters with [campsite = [campsite] of myself ] [set heading [heading] of myself] ;;
        ]
      ]
    ]
  ]
  while [allhuntersdone = 0]
    [
      ask hunters with [done = 0][
        set timecamp distance campsite * time-walk-cell                             ; expected time (in minutes) for an forager to walk straight back to the camp
        ifelse time-forage-budget > timecamp                                       ; true if time budget is less than the time it takes to cross a cell (aka time to go home)
          [ ; time left for hunting
            ; so hunter moves to search
            move-hunt
            set time-forage-budget time-forage-budget - time-walk-cell
            set dailykm dailykm + .1
            encounterprocedure-wrd
          ]
          [ ;else no time left, head home
            face campsite
            let found 0
            ifelse [vt] of patch-ahead 1 > 0   ;look for viable patch straight ahead
            [
              move-to patch-ahead 1 set found 1
            ][                                 ;no viable patch straight ahead so repeat turning and trying again
              while [found = 0]
              [
                rt random 45 lt random 45
                if patch-ahead 1 != nobody [
                  if [vt] of patch-ahead 1 > 0 [move-to patch-ahead 1 set found 1]
                ]
              ]
            ] ;close else patch-ahead
            set time-forage-budget time-forage-budget - time-walk-cell
            set dailykm dailykm + .1
            encounterprocedure-wrd
          ] ; close else time left
        set timecamp distance campsite * time-walk-cell
        if (distance campsite < 1.5 AND time-forage-budget < time-walk-cell) OR time-forage-budget < 0 [      ;next to or at campsite and foraging time has run out OR time has run out
          let d distance campsite
          move-to campsite ;teleports foragers home if they've harvested enough
          set dailykm dailykm + d
          set done 1 ; they're consistently over-shooting their foraging budget since they check time against current patch, then move to a patch w/ different harvest time
        ]

      ] ;close ask hunters
      if sum [done] of hunters = count hunters [
        set allhuntersdone 1
        ask hunters with [dailykcal < 3000]
        [
          set days_without3000 days_without3000 + 1
          if dailykcal < 1500 [set days_without1500 days_without1500 + 1]
        ]
        ask camps [
          set kcal_per_day kcal_per_day + sum [dailykcal] of hunters with [campsite = myself]
          ;; ADDED record the kcal from meat at the patch
          set total-kcal-meat lput sum [dailykcal] of hunters with [campsite = myself] total-kcal-meat
          ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
        ]
      ]
    ]  ;close while
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to move-gather
  ifelse forager-movement = "random" [
    let p one-of neighbors with [current_kcal_return > 0]
    ifelse p != nobody [move-to p][move-to one-of neighbors with [vt > 0]]
    set time-forage-budget time-forage-budget - time-walk-cell
    update-gather-numbers
  ]
  [  ; find best patch within vision radius, then move to that patch
    let best-patch self
    ifelse days-until-tide <= 0 [
      set best-patch pick-patch-local-tidal
    ][
      set best-patch max-one-of patches in-radius vision-forager [current_kcal_return * ([time-forage-budget] of myself - (time-walk-cell * distance myself))]
    ]
    ifelse best-patch != patch-here and [current_kcal_return] of best-patch > 0
    [
      ifelse distance best-patch < 1.5                       ;if neighbouring cell move there then harvest, else move towards but don't harvest on the way
      [
        move-to best-patch
        set time-forage-budget time-forage-budget - time-walk-cell
        update-gather-numbers
      ][ ;else farther so walk towards
        face best-patch
        ifelse is-patch? patch-ahead 1 and [vt > 0] of patch-ahead 1 [
          move-to patch-ahead 1
          set time-forage-budget time-forage-budget - time-walk-cell
          set dailykm dailykm + .1
        ][ ;else     if you can't move to or towards the best, move anywhere!
          move-to one-of neighbors with [vt > 0]
          update-gather-numbers
        ]
      ] ;close if distance
    ]
    [
      let p one-of neighbors with [current_kcal_return > 0]
      ifelse p != nobody [move-to p][move-to one-of neighbors with [vt > 0]]
      set time-forage-budget time-forage-budget - time-walk-cell
      update-gather-numbers
    ]
  ]
end

to move-hunt
  ifelse forager-movement = "random" [
    move-to one-of patches in-radius 1.5 with [vt > 0]
  ][;else all hunters pick a direction and spread while walking (much simpler version of Ache model's flocking)
    ifelse random 2 = 0 [left random 15][right random 15]
    let p patch-ahead 1
    while [not is-patch? p or [vt = 0] of p] [set heading heading - 180 + (45 - random 90) set p patch-ahead 1]
    move-to p
  ] ;close spread walk
end



to-report pick-patch-global                  ;currently assuming that every camp has full knowledge of other camps.
    report max-one-of patches-vt [current_kcal_return * (daily-time-budget - (time-walk-cell * distance myself))]                   ;this doesn't work because camp-mobility is restricted, also camps set out for tide even if not going to make it before end of spring tide
end

to-report pick-patch-global-tidal-foresight          ;clone of the local version but for the full land patch set instead of just in-radius
  ifelse is-camp? self
  [
     let p max-one-of patches-vt [
      ifelse-value goodcoast?
      [
        ;next line is for coastal cells, it adds calories for 2 h of coastal foraging and rest of day of terrestrial foraging on the nearest terrestrial cell, then subtracts out calories lost from traveling instead of foraging in place as usual.
        ((ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]) * 2) + ([ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]] of one-of patches in-radius 2 with [vt > 0 AND vt < 10] * (daily-time-budget - 2)) - (distance myself / camp-mobility * daily-time-budget * current_kcal_return)

      ]
      [
        (ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]) * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * current_kcal_return)
      ]
    ]
    report p
  ]
  [
    print "Don't use for foragers"
    report one-of patches
  ]
end

to-report pick-patch-local

  ifelse is-camp? self ;allows same function to be used by camps and foragers
  [
    report max-one-of patches in-radius camp-mobility [current_kcal_return * (daily-time-budget - (time-walk-cell * distance myself))]
  ]
  [
    report max-one-of patches in-radius vision-forager [(current_kcal_return * ([time-forage-budget] of myself - (time-walk-cell * distance myself)))]
  ]
end

to-report pick-patch-local-tidal
  ; calculates the best patch to gather when the tide is right for shellfish gathering
    let coastpatch min-one-of patches-coast [distance myself]
    ifelse (time-forage-budget > daily-time-budget - 2) and ((time-forage-budget < (time-walk-cell * (distance coastpatch))))          ;low tide coastal or terrestrial, after that terrestrial only. problem since 2 tides a day, could have used torches for new moon, even without on full. Change to 4 hours and ignore that they're not sequential?
    [
      let p max-one-of (patch-set patches in-radius vision-forager patches-coast) [current_kcal_return * (2 - (daily-time-budget - [time-forage-budget] of myself) - (time-walk-cell * distance myself))]
      report p
    ]
    [ ;else rest of day on terrestrial
      let p max-one-of patches in-radius vision-forager [(ifelse-value (goodcoast? AND current_kcal_return > 0) [kcal_return_min][current_kcal_return]) * ([time-forage-budget] of myself - (time-walk-cell * distance myself))]
      report p
    ]
end

to-report pick-patch-local-tidal-foresight   ;CW this is called by spatial-foresight-movement and is the decision making core of the model.
  ifelse is-camp? self
  [
    let p max-one-of (patch-set patches in-radius camp-mobility patches-coast) [
      ifelse-value goodcoast?
      [
        ((ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]) * 2) + ([ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]] of one-of patches in-radius 2 with [vt > 0 AND vt < 10] * (daily-time-budget - 2)) - (distance myself / camp-mobility * daily-time-budget * current_kcal_return)
      ]
      [
        (ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]) * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * current_kcal_return)
      ]
    ]
    report p
  ]
  [
    print "Don't use for foragers"
    report one-of patches
  ]

end

to-report pick-patch-hunt    ;called by camps, non-foresight deprecated
  let whichcamp who
  let p max-one-of patches with [item whichcamp timelast < (ticks - recoverytime)] [
    hunt_kcal_return * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * hunt_kcal_return)
  ]
  report p
end

to-report pick-patch-hunt-foresight    ;called by camps
  let whichcamp who
  let p max-one-of patches with [item whichcamp timelast < (ticks - recoverytime)] [
    hunt_temporal_multiplier * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * hunt_kcal_return)
  ]
  report p
end

to-report pick-patch-huntstep   ;called by one hunter per camp during day's init
  let whichcamp [who] of campsite
  let p max-one-of other patches in-radius vision-forager [
    hunt_kcal_return * ([time-forage-budget] of myself - (time-walk-cell * distance myself))
  ]
  report p
end

to-report pick-patch-local-tidal-foresight_image
  let p max-one-of (patch-set patches in-radius camp-mobility patches-coast) [
    ifelse-value goodcoast?
    [
      ((ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]) * 2) +
      ([ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]] of one-of patches in-radius 2 with [vt > 0 AND vt < 10] * (daily-time-budget - 2)) -
      (distance myself / camp-mobility * daily-time-budget * current_kcal_return)
    ]
    [
      (ifelse-value (current_kcal_return > 0) [temporal_multiplier] [0]) * daily-time-budget - (distance myself / camp-mobility * daily-time-budget * current_kcal_return)
    ]
  ]
  report p
end

to-report pick-patch-local-tidal-land     ;CW logic wrapped into pick-patch-local-tidal-foresight
  let p max-one-of (patch-set patches in-radius vision-forager with [vt > 0] patches-coast)
    [
      max (list
        ;marine: if (daily-left) + travel < tide, tide - (daily-left) - travel, 0
        ((current_kcal_return * (ifelse-value ((daily-time-budget - [time-forage-budget] of myself) + (time-walk-cell * distance myself) < 2) [2 - (daily-time-budget - [time-forage-budget] of myself) - (time-walk-cell * distance myself)][0])) +
        ;terrestrial: if (daily-left) + travel < tide, daily-tide, left-travel
          ([current_kcal_return] of one-of patches in-radius 1.5 with [vt > 0 AND vt < 10] * ;flags if local cells empty, switch to mini max-one-of?
            ifelse-value ((daily-time-budget - [time-forage-budget] of myself) + (time-walk-cell * distance myself) < 2) [daily-time-budget - 2] [[time-forage-budget] of myself - (time-walk-cell * distance myself)]
            ))
        ((ifelse-value (goodcoast? AND current_kcal_return > 0) [kcal_return_min] [current_kcal_return]) * ([time-forage-budget] of myself - (time-walk-cell * distance myself)))
      )
    ]
  report p
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to encounterprocedure ; check whether a species is encountered, deprecated
  if random-float 1 > probnoencounter [
    let species []
    set species listspecies
    set counted 0
    while [counted < nrspecies] ; we go randomly through the species list and stop if we encounter an animal of a species
    [
      let draw one-of species
      updatespecies draw
      set species remove draw species
      set counted counted + 1
    ]
  ]
end

to encounterprocedure-wrd ; check whether a species is encountered
  ;new weighted random draw method for encounterprocedure using the Rnd extension
  ;works very similarly to old but fixes an issue in old where every turn they tried to encounter every species
  ;and runs much faster
  if random-float 1 > probnoencounter [
     if [vt] of patch-here > 0 [
      let draw position rnd:weighted-one-of-list encounter [[p] -> p] encounter
      if item draw time-until-mammal = 0 [updatespecies draw]
    ]
  ]
end

; for each type of encounter we add the average time for each pursuit and the probability of a successful hunt (including the options of cooperative hunting)
to updatespecies [draw] ; for a given species
  let exp-rt-rate item draw rt-rate
  let campself campsite
  if exp-rt-rate >= avgpastrr [                  ; avgpastrr is the average return rate over the last x days, so if the return rate of the mammal caught is higher or equal to the average...
    set campself campsite
    set potmeat 0
    set counted 100
    set pursuit random-normal item draw pursuit-time item draw pursuit-time-sd
    set hunt-time replace-item draw hunt-time (item draw hunt-time + pursuit)
    set time-forage-budget time-forage-budget - pursuit

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;PROJECTILE DISCARD ADDITION ;;
    ;; CHANGED IF TO IFELSE

    let usingProjectile? random 100 < point-hunting-rate ;; temp variable that identifies if the hunter is using a projectile or not

    ifelse random-float 1 < random-normal item draw success-rate item draw success-rate-sd [
      updatemeat item draw prey_cal
      set potmeat item draw prey_cal

      ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;PROJECTILE DISCARD ADDITION ;;
      if usingProjectile? [  ; successfull-throw is only called if the hunter was using a projectile to hunt the prey
        successful-throw draw  ;; draw corresponds to the position of the animal in the list
      ]
      ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

      set time-until-mammal replace-item draw time-until-mammal 7          ;arbitrary encounter supression length in days. Does this make sense for small prey like Hyrax?
    ][


      ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;; PROJECTILE DISCARD ADDITION ;;
      if usingProjectile? [  ; miss-throw is only called if the hunter was using a projectile to hunt the prey
        miss-throw
      ]
    ]
    ;; Check if the spear is broken, which will determine if it gets discarded
    check-broken-spear
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    set dailykcal dailykcal + potmeat
    set dailykcal_hunt dailykcal
  ]
end

to updatereturnrate [tim]
  if [vt] of patch-here = 1 [set time_vt replace-item 0 time_vt (item 0 time_vt + tim)]
  if [vt] of patch-here = 2 [set time_vt replace-item 1 time_vt (item 1 time_vt + tim)]
  if [vt] of patch-here = 3 [set time_vt replace-item 2 time_vt (item 2 time_vt + tim)]
  if [vt] of patch-here = 4 [set time_vt replace-item 3 time_vt (item 3 time_vt + tim)]
  if [vt] of patch-here = 5 [set time_vt replace-item 4 time_vt (item 4 time_vt + tim)]
  if [vt] of patch-here = 6 [set time_vt replace-item 5 time_vt (item 5 time_vt + tim)]
  if [vt] of patch-here = 8 [set time_vt replace-item 6 time_vt (item 6 time_vt + tim)]
  if [vt] of patch-here = 9 [set time_vt replace-item 7 time_vt (item 7 time_vt + tim)]
  if [vt] of patch-here = 10 [set time_vt replace-item 8 time_vt (item 8 time_vt + tim)]
  if [vt] of patch-here = 12 [set time_vt replace-item 9 time_vt (item 9 time_vt + tim)]
  if [vt] of patch-here = 13 [set time_vt replace-item 10 time_vt (item 10 time_vt + tim)]
  if [vt] of patch-here = 14 [set time_vt replace-item 11 time_vt (item 11 time_vt + tim)]

end

to updatemeat [kcal]
  if [vt] of patch-here = 1 [set meat_vt replace-item 0 meat_vt (item 0 meat_vt + kcal)]
  if [vt] of patch-here = 2 [set meat_vt replace-item 1 meat_vt (item 1 meat_vt + kcal)]
  if [vt] of patch-here = 3 [set meat_vt replace-item 2 meat_vt (item 2 meat_vt + kcal)]
  if [vt] of patch-here = 4 [set meat_vt replace-item 3 meat_vt (item 3 meat_vt + kcal)]
  if [vt] of patch-here = 5 [set meat_vt replace-item 4 meat_vt (item 4 meat_vt + kcal)]
  if [vt] of patch-here = 6 [set meat_vt replace-item 5 meat_vt (item 5 meat_vt + kcal)]
  if [vt] of patch-here = 8 [set meat_vt replace-item 6 meat_vt (item 6 meat_vt + kcal)]
  if [vt] of patch-here = 9 [set meat_vt replace-item 7 meat_vt (item 7 meat_vt + kcal)]
  if [vt] of patch-here = 10 [set meat_vt replace-item 8 meat_vt (item 8 meat_vt + kcal)]
  if [vt] of patch-here = 12 [set meat_vt replace-item 9 meat_vt (item 9 meat_vt + kcal)]
  if [vt] of patch-here = 13 [set meat_vt replace-item 10 meat_vt (item 10 meat_vt + kcal)]
  if [vt] of patch-here = 14 [set meat_vt replace-item 11 meat_vt (item 11 meat_vt + kcal)]

end
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to-report kcal-avg
    report mean [overall_avg_kcal] of camps
end

to display-vt
  ask patches-vt [
    if vt = 1  [set pcolor 88]      ; Freshwater wetlands
    if vt = 2  [set pcolor 86]      ; Alluvial Vegetation
    if vt = 3  [set pcolor 116]     ; Strandveld
    if vt = 4  [set pcolor 16]      ; Saline Vegetation
    if vt = 5  [set pcolor 46]      ; Renosterveld
    if vt = 6  [set pcolor 56]      ; Sand Fynbos
    if vt = 8  [set pcolor 76]      ; Thicket
    if vt = 9  [set pcolor 126]     ; Limestone Fynbos
    if vt = 10 [set pcolor 53]      ; Aeolianite (Coastal)
    if vt = 11 [set pcolor 26]      ; Sandy Beach (Coastal)
    if vt = 12 [set pcolor 34]      ; TMS Boulders (Coastal)
    if vt = 13 [set pcolor 35]      ; TMS Eroded Rocky Headlands (Coastal)
    if vt = 14 [set pcolor 36]      ; TMS Wave Cut Platforms (Coastal)
  ]
end

to display-kcal             ;this is logged ; could be turned to single patch, then ask patches in go code... avoid dupe in update-patches
  let max-cal 750
  ask patches-vt [
    ifelse current_kcal_return > 0 [set pcolor scale-color green current_kcal_return 0 max-cal][set pcolor 2]
  ]
end

to display-hybrid     ; replace with a vt or black version
    ask patches-vt [
    if vt = 1  [set pcolor 88 - (1 - current_kcal_return / kcal_return)]      ; Freshwater wetlands
    if vt = 2  [set pcolor 86 - (1 - current_kcal_return / kcal_return)]      ; Alluvial Vegetation
    if vt = 3  [set pcolor 116 - (1 - current_kcal_return / kcal_return)]     ; Strandveld
    if vt = 4  [set pcolor 16 - (1 - current_kcal_return / kcal_return)]      ; Saline Vegetation
    if vt = 5  [set pcolor 46 - (1 - current_kcal_return / kcal_return)]      ; Renosterveld
    if vt = 6  [set pcolor 56 - (1 - current_kcal_return / kcal_return)]      ; Sand Fynbos
    if vt = 8  [set pcolor 76 - (1 - current_kcal_return / kcal_return)]      ; Thicket
    if vt = 9  [set pcolor 126 - (1 - current_kcal_return / kcal_return)]     ; Limestone Fynbos
    if vt = 10 [set pcolor 53 - (1 - current_kcal_return / kcal_return)]      ; Aeolianite (Coastal)
    if vt = 11 [set pcolor 26 - (1 - current_kcal_return / kcal_return)]      ; Sandy Beach (Coastal)
    if vt = 12 [set pcolor 34 - (1 - current_kcal_return / kcal_return)]      ; TMS Boulders (Coastal)
    if vt = 13 [set pcolor 35 - (1 - current_kcal_return / kcal_return)]      ; TMS Eroded Rocky Headlands (Coastal)
    if vt = 14 [set pcolor 36 - (1 - current_kcal_return / kcal_return)]      ; TMS Wave Cut Platforms (Coastal)
  ]
end

to-report patches-at-radius [rad]
    report (patch-set patches-vt with [distance myself > rad - 1 AND distance myself <= rad])
end

to display-none
  if ticks <= 1 [display-vt]
end

to display-time-replenished
  ask patches-vt
  [
    if ticks > 0 [set pcolor scale-color red time-until-replenished 365 0]
  ]
end

to display-kcal-gathered
  let max-harvest max [kcal-gathered] of patches-vt
  ask patches-vt
  [
    if ticks > 0 [set pcolor scale-color red kcal-gathered 0 (max-harvest + 1)]
  ]
end

to display-times-camped ;frequency of camps on each cell
  let max-camped max [times-camped] of patches-vt
  let mean-camp mean [times-camped] of patches-vt
  let stdev-camp standard-deviation [times-camped] of patches-vt
  ask patches-vt
  [
    set pcolor white
    if ticks > 1 and times-camped > 0 [
      set pcolor red + 3
      if times-camped > ticks * .001 [set pcolor red]
    ]

  ]
end

to update-gather-numbers          ; this is the accounting of harvesting foragers and depleting patches
  let harvested_kcal pass-harvest-time * current_kcal_return
  set dailykcal dailykcal + harvested_kcal
  ifelse vt < 10 [set dailykcal_plant dailykcal_plant + harvested_kcal][set dailykcal_shell dailykcal_shell + harvested_kcal

  ;;;;;;;;;;;;;;;;;;;;;;;;
  ;; **Coastal addition
    let d distance campsite ; calculates the distance to its camp
    ifelse d > onsiteProcessThreshold [ ; this is if people have to do some processing onsite.
      set onsiteProcessing? true ;show (word "processing onsite " patch-here " here's what I caught: " harvested_kcal)
      set total-kcal-shell-process lput harvested_kcal total-kcal-shell-process ; whatever is collected is visible on the spot (onsite processing)
    ][
      set onsiteProcessing? false ;show (word "processing at camp " campsite " that much food: " harvested_kcal)
      ask [ patch-here ] of campsite [
        set total-kcal-shell-temp lput harvested_kcal total-kcal-shell-temp
      ]
    ]
  ]
  ;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;

  set dailykm dailykm + .1       ;jan16 with the walk to target just implemented, foragers aren't counting km when just traveling
  ifelse total-harvest-time > 0
  [
    set time-forage-budget time-forage-budget - pass-harvest-time
    ask patch-here [
      set total-harvest-time total-harvest-time - pass-harvest-time
      set kcal-gathered kcal-gathered + harvested_kcal            ;total for a run, not rolling...
      if total-harvest-time <= 0 [set total-harvest-time 0 set current_kcal_return 0 set time-until-replenished 365 set pcolor black]

    ]
  ][ ;else already all harvested
    set time-forage-budget time-forage-budget - time-walk-cell
  ]
end

to update-camp-numbers
  ask camps [
    ifelse kcal_per_day / my_camp_size < 3000 [
      set days_without3000 days_without3000 + 1
      set color orange
      if kcal_per_day / my_camp_size < 1500 [ set days_without1500 days_without1500 + 1 set color orange - 2]
    ][
      set color red
    ]
    ifelse length hist_kcal_per_day < memoryfood
      [set hist_kcal_per_day lput (kcal_per_day / (count foragers with [campsite = myself])) hist_kcal_per_day ]
      [
        set hist_kcal_per_day butfirst hist_kcal_per_day
        set hist_kcal_per_day lput (kcal_per_day / (count foragers with [campsite = myself])) hist_kcal_per_day
      ]
    set kcal_total kcal_total + kcal_per_day
    set overall_avg_kcal mean [hist_kcal_per_day] of self
    set total-harvest-time 0 set current_kcal_return 0 set time-until-replenished 365 set pcolor black
  ]
end

to-report var_kcal_return [kcal_mean kcal_stdev]         ;instead of a constant rate of return, this will pull a number from mean and stdev
  let c random-normal kcal_mean kcal_stdev
  ifelse c > 0 [report c][report 0]
end

;;;;;;;;;;;;;;;;;;;;;;;;;
;;; VARIANT PROCEDURES ;;
;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; HUNTER PROCEDURE DISCARD if the tool is broken ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to check-broken-spear

  let array-index-broken table:get point-table "broken"       ;; Identifies the array index that corresponds to broken
  let array-index-embedded table:get point-table "embedded"   ;; Identifies the array index that corresponds to embedded points
  if array:item projectile array-index-broken = true          ;; If the projectile point is broken (but not embedded), it is discarded where it broke
  [ if array:item projectile array-index-embedded = false
    [ discard-on-spot ]]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; HUNTER PROCEDURE to bring back embedded points into the carcass to the camp ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to check-transport [ x ]  ;; Here x refers to the body part hit by the spear

;; The list of values correspond to the following body parts:
;; Body cavity
;; Femur
;; Humerus
;; Pelvis
;; Radius Ulna
;; Rib cage
;; Scapula
;; Vertebrae
;; Kill zone

  let y random-float 1                                        ;; Selects a random number between 0 and 1, which will be compared with the probabilities below
  let prob ( list .53 .67 .71 .92 .69 .53 .67 .91 .53 )       ;; These values come from Schoville and Otarolla-Castillo's 2014 paper on body part transport

  ifelse y < item x prob                                      ;; If the random number is lower than the probability of bringing back a certain body part, the embedded spear is dropped at the camp
    [ discard-at-camp ]
    [ discard-on-spot ]                                       ;; If it's not dropped at the camp, it is discarded at the hunting spot.

end

;;;;;;;;;;;;;;;;;;;;;;
;; HUNTER PROCEDURE ;;
;;;;;;;;;;;;;;;;;;;;;;

to create-new-point

  set projectile array:from-list n-values 6 [ 0 ]                                   ;; Creates a new projectile point
  array:set projectile (table:get point-table "embedded") false                     ;; By default, all new points are NOT embedded  (the "table:get" simply returns the item's position for "embedded")
  array:set projectile (table:get point-table "broken") false                       ;; By default, all new points are NOT broken

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; OBSERVER PROCEDURE to create a master table that identifies the item position of each variable (for code clarity) ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to create-point-table

  set point-table table:make                          ;; Table that will identify which index of the projectile array is what key
  table:put point-table "key" "index"                 ;; For easier visualization of which values are what
  table:put point-table "success counter" 0           ;; This item will be the number of success hits
  table:put point-table "miss counter" 1              ;; This item will be the number of misses
  table:put point-table "species counter" 2           ;; This item will be the kcal of the last prey hunted
  table:put point-table "embedded" 3                  ;; This item will identify if a point is embedded or not
  table:put point-table "broken" 4                    ;; This item will identify if a point is broken or not
  table:put point-table "place of discard" 5          ;; This item will record where the point got discarded

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; HUNTER PROCEDURE DISCARD the spear at camp ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to discard-at-camp

  let array-index-discard table:get point-table "place of discard"       ;; Identifies the array index that corresponds to the place of discard
  array:set projectile array-index-discard "camp"                        ;; Identifies that the point is discarded at the camp

  let patch-under-camp 0                                   ;; Temporary variable that will be populated by the camp
  let artifact projectile

  ask campsite
  [ set patch-under-camp patch-here ]                      ;; The camp identifies the patch underneath itself (which will take the projectile values)

  ask patch-under-camp
  [ set assemblage lput artifact assemblage ]              ;; Asks the patch under the camp to take on the value of the artifact embedded/broken in the animal transported back to camp

  create-new-point                                         ;; Creates a new projectile point

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; HUNTER PROCEDURE DISCARD if the tool is broken ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to discard-on-spot

  let array-index-discard table:get point-table "place of discard"       ;; Identifies the array index that corresponds to the place of discard
  array:set projectile array-index-discard "lost"                        ;; Identifies that the point is discarded at the hunting spot

  let artifact projectile

  ask patch-here
  [ set assemblage lput artifact assemblage ]                ;; Asks the patch where the agent stands to take on the value of the artifact produced

  create-new-point                                           ;; Creates a new projectile point

end

;;;;;;;;;;;;;;;;;;;;;;;;
;; OBSERVER PROCEDURE ;;
;;;;;;;;;;;;;;;;;;;;;;;;

to export-values

  ; To export the artifact values from the patches to the csv

  file-open file

  let text-out 0

  ask patches
  [ if site? > 0 or total-kcal-shell-process != []
    [ let length-assemblage length [ assemblage ] of self
      set text-out (sentence "," behaviorspace-run-number "," nrcamps "," spatial-foresight "," daily-time-budget "," hunter-percent "," vision-forager ","
         forager-movement "," nrforagers "," days_of_foresight "," global-knowledge? "," walk-speed "," pxcor "," pycor "," site? "," length-assemblage "," vt "," mean [dailykcal] of foragers ","
         total-kcal-shell "," total-kcal-shell-process "," total-kcal-plant "," total-kcal-meat "," previous-vt "," onsiteProcessThreshold "," ticks ",")
        file-type text-out
        file-print "" ]
    ]
  file-close

end

;;;;;;;;;;;;;;;;;;;;;;;;;;
;; FOR HPC outputs only ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report export-values-HPC

  let filename file
  file-open filename
  ;;create the file header
  let text-out (sentence ",bs.run.number,n.camps,spatial.foresight,daily.time.budget,hunter.percent,vision.forager,forager.movement,n.foragers,days.foresight,global.knowledge,walk.speed,xcor,ycor,site,length.assemblage,vegetation,mean.kcal,totalKcalShell,totalKcalShellProcess,totalKcalPlant,totalKcalMeat,previousVt,onsiteProcessThreshold,ticks,")
  file-type text-out
  file-print ""

  ask patches [
    if site? > 0 or total-kcal-shell-process != []
    [ let length-assemblage length [ assemblage ] of self
      set text-out (sentence "," behaviorspace-run-number "," nrcamps "," spatial-foresight "," daily-time-budget "," hunter-percent "," vision-forager ","
        forager-movement "," nrforagers "," days_of_foresight "," global-knowledge? "," walk-speed "," pxcor "," pycor "," site? "," length-assemblage "," vt "," mean [dailykcal] of foragers ","
        total-kcal-shell "," total-kcal-shell-process "," total-kcal-plant "," total-kcal-meat "," previous-vt "," onsiteProcessThreshold "," ticks ",")
        file-type text-out
        file-print ""
    ]
  ]

  file-close

  report "bogus"  ;; Because we don't actually report anything, but a reporter needs to have a "report" action

end

;; Troublehooting procedure

;to-report foragerShellfish ; this is to produce a graph of the daily shellfish calories per forager
;
;  let filename file
;  file-open filename
;  ;;create the file header
;  let text-out (sentence ",bs.run.number,forager.id,daily.kcal.shell,tick,")
;  file-type text-out
;  file-print ""
;
;  ask foragers [
;    set text-out (sentence "," behaviorspace-run-number "," self "," dailykcal_shell "," ticks ",")
;    file-type text-out
;    file-print ""
;  ]
;
;  file-close
;
;  report "bogus"
;
;end

;;;;;;;;;;;;;;;;;;;;;;
;; HUNTER PROCEDURE ;;
;;;;;;;;;;;;;;;;;;;;;;

to miss-throw

  let array-index-miss table:get point-table "miss counter"       ;; Identifies the array index that corresponds to miss counter
  let miss-counter array:item projectile array-index-miss         ;; Reports the array item that correspond to the miss counter index
  array:set projectile array-index-miss ( miss-counter + 1 )      ;; Adds one to the miss counter of the projectile

  ;; The fracture impact varies based on the environment in which the hunter is (based on Fischer et al. 1984 data on diagnostic impact frequency)

  ;; vt1 = freshwater wetlands (bushbuck, bushpig, and grey duiker)
  ;; vt2 = Floodplain woodland vegetation (bushbuck, and bushpig)
  ;; vt3 = strandveld (bushbuck, bushpig, grey duiker, and grysbok)
  ;; vt4 = saline vegetation (no hunting)
  ;; vt5 = renosterveld (bushbuck, bushpig, grey duiker, and grysbok)
  ;; vt6 = sand fynbos (bushbuck, bushpig, grey duiker, and grysbok)
  ;; vt7 = N/A
  ;; vt8 = Albany thicket (bushbuck, bushpig, grey duiker, and grysbok)
  ;; vt9 = limestone fynbos (bushbuck, bushpig, grey duiker, and grysbok)
  ;; vt10-14 = Aeoliniate and TMS (hyrax)

  let vt-h [ vt ] of patch-here         ;; Identifies the habitat where the hunt is taking place
  let p random-float 1                  ;; Temporary random value to see which plant was hit
  let p2 random-float 1                 ;; Temporary random value to see if damage is caused by hitting the plant
  let damaged? 0                        ;; Temporary varible to change the point's values later on.

  ifelse vt-h < 10 [     ;;; This covers the environments with vegetation
    ifelse p < item 0 table:get habitat-hit-table vt-h    ;; This asks if p is lower than the first probability (tree probability) associated with the vt-h (vt of patch-here)
    [ if p2 < 0.6                                         ;; Only 60%* of trees hit will break the point
      [ set damaged? "tree" ]]
    [ ifelse p < item 1 table:get habitat-hit-table vt-h  ;; Asks if p is lower than the second probability (bush probability) associated with the vt-h (vt of patch-here)
      [ if p2 < 0.33                                      ;; Only 33%* of bushes hit will break the point
        [ set damaged? "bush" ]]
      [ if p < item 2 table:get habitat-hit-table vt-h    ;; Asks if p is lower than the third probability (grass probability) associated with the vt-h (vt of patch-here)
        [ if p2 < 0.14                                    ;; Soil and grass cause damage only 14%* of the time
          [ set damaged? "grass" ]]]]]                    ;; If p was not lower than any of the other probabilities, it has to be below reed (as the probabilities are cumulative), but reed does not damage the point
  [ if p < .7
    [ set damaged? "rock" ]]             ;;; In rocky environments, we assume that breakage will be common when the prey is missed (more common than when hitting a tree).

  ;; * Fischer et al. 1984
  ;; These determine if the projectile point is broken and thus discarded
  let array-index-broken table:get point-table "broken"       ;; Identifies the array index that corresponds to broken
  if damaged? != 0                                            ;; If there is some damage (no matter the source), the stone will be broken
  [ array:set projectile array-index-broken true ]            ;; Replaces the array item by a "true" (which says that the point was broken)

end

to-report prob-body-part

  ;; These values come from Schoville and Otarolla-Castillo 2010's poster on their experimental work with projectile points

  let y random-float 1

  ;; The list of values correspond to the following body parts:
  ;; Body cavity
  ;; Femur
  ;; Humerus
  ;; Pelvis
  ;; Radius Ulna
  ;; Rib cage
  ;; Scapula
  ;; Vertebrae
  ;; Kill zone

  let weights ( list .45 .03 .03 .03 .04 .15 .07 .14 .06 )
  let prob ( list 0 1 2 3 4 5 6 7 8 )
  let pairs ( map list prob weights )

  ;; rnd:weighted-one-of-list reports a random agent from the 'pairs' list. The probability of being picked is based on the weight of each item.
  let i rnd:weighted-one-of-list pairs [[ p ] -> last p ]

  report first i  ;; This reports the chosen body part (based on probability of hitting)

end

to-report prob-break [ x ] ;; x is the body part identified by prob-body-part

  ;; These values come from Ben Schoville's poster on the probabilities of embedding and breakage.

  ;; The list of values correspond to the following body parts:
  ;; Body cavity
  ;; Femur
  ;; Humerus
  ;; Pelvis
  ;; Radius Ulna
  ;; Rib cage
  ;; Scapula
  ;; Vertebrae
  ;; Kill zone

  let prob ( list 0.137 0.195 0.172 0.386 0.656 0.111 0.188 0.186 0.176 )

  ifelse random-float 1 < item x prob               ;; If y is lower than the probability of breakage associated with the chosen location, the point breaks
  [ report true ]
  [ report false ]

end

to-report prob-embed [ x ] ;; x is the body part identified by prob-body-part

  ;; These values come from Ben Schoville's poster on the probabilities of embedding and breakage.

  ;; The list of values correspond to the following body parts:
  ;; Body cavity
  ;; Femur
  ;; Humerus
  ;; Pelvis
  ;; Radius Ulna
  ;; Rib cage
  ;; Scapula
  ;; Vertebrae
  ;; Kill zone

  let prob ( list 0.127 0.196 0.045 0.158 0.028 0.127 0.061 0.132 0.100 )

  ifelse random-float 1 < item x prob                 ;; If the random value between 0-1 is lower than the probability of embedding associated with the chosen location, the point gets embedded
  [ report true ]
  [ report false ]

end

;;;;;;;;;;;;;;;;;;;;;;
;; HUNTER PROCEDURE ;;
;;;;;;;;;;;;;;;;;;;;;;

to successful-throw [ y ]   ;; y is for the item of the species hunted (so we add the size in the list)

  ;; This adds damage to specific parts on a tool
  ;; The values in the foreach list represent the positions on the point that get affected by the impact

  ;; Updates the number of successful throws logged by the tool
  let array-index-success table:get point-table "success counter"
  let success-counter array:item projectile array-index-success                      ;; Reports the item in the array that corresponds to the number of success counter (in the point-table)
  array:set projectile array-index-success ( success-counter + 1 )                   ;; Adds one to the success counter

  ;; This adds the animal size to the assemblage list
  ;; Has to be based on the calories gathered (in the hunting submodel)

  ;; Bushbucks = 163,800 (medium, like a deer) about 95 lbs
  ;; Bushpig = 170,625 (medium, like a big boar) 150 lbs
  ;; Grey duiker = 14,430 (medium, also like a small deer) 34 lbs
  ;; Grysbok = 7800 (small, like a baby deer) 21 lbs
  ;; Hyrax = 7800 (small thing, kinda marmot-like) about 6-7 lbs

  let prey-size item y prey_cal
  let array-index-species table:get point-table "species counter"        ;; Identifies the array index that corresponds to species counter
  let species-counter array:item projectile array-index-species          ;; Reports the array item that corresponds to the species counter key in the table
  array:set projectile array-index-species prey-size                     ;; Adds the prey-size of the killed animal to that item

  ;; Identifies the body part hit (as a probability based on Schoville's data), which will affect the probability of breakage and embedding.
  set body-part prob-body-part

  ;; Determines if the point gets embedded and/or broken when hitting that specific body part
  let array-index-embedded table:get point-table "embedded"
  array:set projectile array-index-embedded prob-embed body-part         ;; Calls the prob-embed reporter. These points will have some chances of making it back to camp WITHIN the prey's carcass
  let array-index-broken table:get point-table "broken"
  array:set projectile array-index-broken prob-break body-part           ;; Calls the prob-break reporter. These points get discarded where they were broken

  ;; If the point is embedded in the animal, it may be left there or transported back to camp with the meat.
  if array:item projectile array-index-embedded = true
  [ let p random 100
    ifelse p < point-recycling and array:item projectile array-index-broken = false    ;; However, a certain % of the time, regardless of where the points gets embedded, it will be reused if it's not broken.
    [ array:set projectile array-index-embedded false ]                  ;; This signifies that the point gets recycled (the embedded index gets reset)
    [ ifelse prey-size < 100000                             ;; If it's not recycled, and the prey is small (Set at 100,000 kcal, because Monahan 1998 says size 2 is between 50-250 lb, and Grey Duiker (14,430 kcal) is only 34 lb)...
      [ discard-at-camp ]                                   ;; ... the carcass is transported in full, so the point is discarded at the camp
      [ check-transport body-part ]]]                       ;; If the prey is bigger, there is a possibility that that specific body part will be - or not - transported to camp with the embedded point

end
@#$#@#$#@
GRAPHICS-WINDOW
224
10
757
369
-1
-1
1.75
1
10
1
1
1
0
0
0
1
0
299
0
199
0
0
1
ticks
30.0

BUTTON
3
10
126
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
3
43
126
76
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
4
147
127
180
nrforagers
nrforagers
nrcamps
400
60.0
nrcamps
1
total
HORIZONTAL

BUTTON
3
76
126
109
tick
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
3
428
126
473
forager-movement
forager-movement
"random" "local-patch-choice"
1

PLOT
769
370
1245
611
Proportion gathered by habitat
Days passed
Proportion Gathered/Habitat
0.0
10.0
0.0
0.5
true
true
"" ""
PENS
"Freshwater wetlands" 1.0 0 -4528153 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 1] / sum [kcal-gathered] of patches]]"
"Alluvial" 1.0 0 -8990512 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 2] / sum [kcal-gathered] of patches]]"
"Strandveld" 1.0 0 -6917194 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 3] / sum [kcal-gathered] of patches]]"
"Saline" 1.0 0 -2139308 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 4] / sum [kcal-gathered] of patches]]"
"Renosterveld" 1.0 0 -987046 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 5] / sum [kcal-gathered] of patches]]"
"Sand Fynbos" 1.0 0 -8732573 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 6] / sum [kcal-gathered] of patches]]"
"Thicket" 1.0 0 -11881837 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 8] / sum [kcal-gathered] of patches]]"
"Limestone Fynbos" 1.0 0 -4699768 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 9] / sum [kcal-gathered] of patches]]"
"Aeolianite" 1.0 0 -13210332 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 10] / sum [kcal-gathered] of patches]]"
"Sandy Beach" 1.0 0 -817084 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 11] / sum [kcal-gathered] of patches]]"
"TMS Boulders" 1.0 0 -8431303 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 12] / sum [kcal-gathered] of patches]]"
"TMS Eroded Rocky Headlands" 1.0 0 -6459832 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 13] / sum [kcal-gathered] of patches]]"
"TMS Wave Cut Platforms" 1.0 0 -5207188 true "" "if plots? [if ticks > 1 [plot sum [kcal-gathered] of patches with [vt = 14] / sum [kcal-gathered] of patches]]"

SWITCH
3
517
126
550
spatial-foresight
spatial-foresight
0
1
-1000

PLOT
769
10
969
160
daily kcal
NIL
NIL
0.0
365.0
0.0
5000.0
true
false
"" ""
PENS
"dailykcal" 1.0 0 -7500403 true "" "if plots? [if ticks > 0 [plotxy ticks mean [dailykcal] of foragers]]"
"mean_daily_kcal" 1.0 0 -14439633 true "" ";if plots? [ask camps [plotxy ticks overall_avg_kcal]]\n;if plots? and ticks > 0 [plotxy ticks kcal-avg]"

SLIDER
2
274
125
307
vision-forager
vision-forager
0
75
20.0
5
1
NIL
HORIZONTAL

MONITOR
1062
102
1112
147
NIL
days-until-tide
17
1
11

BUTTON
125
340
196
373
profiler
setup                  ;; set up the model\nprofiler:start         ;; start profiling\nrepeat 1 [ setup ]       ;; run something you want to measure\nprofiler:stop          ;; stop profiling\nprint profiler:report  ;; view the results\nprofiler:reset         ;; clear the data
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
291
421
491
571
Mean daily km
ticks
current-kcal-return
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "if plots? and ticks > 0[plotxy ticks mean [dailykm] of foragers]"

PLOT
492
421
692
571
coast distance
ticks
distance from coast
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "if plots? and ticks > 0  [plotxy ticks mean [distance min-one-of patches with [goodcoast? = true] [distance myself]] of camps]"
"pen-1" 1.0 0 -7500403 true "" "if plots? and ticks > 0  [plotxy ticks standard-deviation [distance min-one-of patches with [goodcoast? = true] [distance myself]] of camps]"

SWITCH
284
385
387
418
plots?
plots?
0
1
-1000

CHOOSER
125
516
248
561
map-zone
map-zone
"z1" "z2" "full"
1

BUTTON
125
373
238
406
profiler module
profiler:start         ;; start profiling\n;ask agents [set time-forage-budget 5.9]\nrepeat 10 [ \nupdate-campsites\n;update-camp-numbers\n;ask hunters [\n;encounterprocedure-wrd\n;encounterprocedure\n;]\n;ask agents [\n;ask pick-patch-local-tidal [set pcolor orange]\n;ask pick-patch-local-tidal-land-old [set pcolor yellow]\n;ask pick-patch-local-tidal-land [set pcolor red]\n;]\n]\n       ;; run something you want to measure\nprofiler:stop          ;; stop profiling\nprint profiler:report  ;; view the results\nprofiler:reset         ;; clear the data
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
125
471
248
516
display-mode
display-mode
"vt" "kcal" "hybrid" "time-replenished" "times-gathered" "times-camped" "none"
6

BUTTON
79
224
134
257
range
  ask one-of camps [\n    ask patches-at-radius camp-mobility [set pcolor red]\n  ]\nask one-of foragers [\n  ask patches-at-radius vision-forager [set pcolor yellow] \n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
2
340
126
385
daily-time-budget
daily-time-budget
4 6 8 10 12
3

SWITCH
3
550
126
583
global-knowledge?
global-knowledge?
0
1
-1000

BUTTON
125
406
238
439
profile-noreset
profiler:start         ;; start profiling\nrepeat 10 [ go ]       ;; run something you want to measure\nprofiler:stop          ;; stop profiling\nprint profiler:report  ;; view the results\nprofiler:reset         ;; clear the data
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
4
180
127
213
nrcamps
nrcamps
0
75
15.0
5
1
NIL
HORIZONTAL

SLIDER
2
307
125
340
walk-speed
walk-speed
1
10
2.0
1
1
km/hr
HORIZONTAL

MONITOR
3
384
125
429
camp-mobility (in cells)
camp-mobility
1
1
11

SLIDER
3
583
126
616
max_kcal_to_harvest
max_kcal_to_harvest
0
10000
10000.0
1000
1
NIL
HORIZONTAL

MONITOR
1012
102
1062
147
NIL
tideday
0
1
11

SLIDER
125
274
217
307
days_of_foresight
days_of_foresight
1
5
5.0
1
1
NIL
HORIZONTAL

BUTTON
125
307
188
340
mob
set camp-mobility daily-time-budget * walk-speed * 10 * .75
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
136
213
217
273
discount_rate
0.1
1
0
Number

SLIDER
126
147
218
180
hunter-percent
hunter-percent
0
1
0.3
.1
1
NIL
HORIZONTAL

MONITOR
1012
57
1062
102
hunters
count hunters
0
1
11

MONITOR
1062
57
1112
102
gathers
count gathers
0
1
11

BUTTON
126
76
189
109
NIL
hunt
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
3
616
126
649
camp-move-threshold
camp-move-threshold
0
5000
2000.0
100
1
NIL
HORIZONTAL

BUTTON
387
385
544
418
go (time_interval)
set kcal_avg_perstep 0\nset coastdist_avg_perstep 0\nset dailykm_avg_perstep 0\nset marine_kcal 0\nrepeat time_interval [go]
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
544
385
701
418
time_interval
time_interval
0
365
365.0
5
1
days
HORIZONTAL

SLIDER
125
439
238
472
recoverytime
recoverytime
0
100
45.0
5
1
NIL
HORIZONTAL

CHOOSER
3
472
126
517
mobility
mobility
"hunter-driven" "gatherer-driven"
1

PLOT
769
160
1146
371
Daily calorie sources
Days passed
Kcal
0.0
365.0
0.0
2000.0
true
true
"" ""
PENS
"Mammals" 1.0 2 -5298144 true "" "if plots? and ticks > 0 [plotxy ticks mean [dailykcal_hunt] of hunters]"
"Plants" 1.0 2 -10899396 true "" "if plots? and ticks > 0 [plotxy ticks mean [dailykcal_plant] of gathers]"
"Marine" 1.0 2 -13345367 true "" "if plots? and ticks > 0 [plotxy ticks mean [dailykcal_shell] of gathers]"

MONITOR
4
218
74
263
NIL
camp_size
0
1
11

SWITCH
406
610
517
643
outputs?
outputs?
0
1
-1000

INPUTBOX
255
610
404
670
max-tick
30.0
1
0
Number

SLIDER
406
646
555
679
point-recycling
point-recycling
0
100
25.0
1
1
NIL
HORIZONTAL

MONITOR
972
10
1112
55
Rolling avg kcal
kcal-avg
0
1
11

TEXTBOX
415
589
565
607
VARIANTS parameters
11
0.0
1

SLIDER
558
646
730
679
point-hunting-rate
point-hunting-rate
0
100
20.0
5
1
NIL
HORIZONTAL

SLIDER
521
610
716
643
onsiteProcessThreshold
onsiteProcessThreshold
0
50
5.0
5
1
NIL
HORIZONTAL

BUTTON
1141
32
1204
65
test
        let a [[1][2][3]]\n        \n        let tempSublist lput 10 last a ; this adds to the latest sublist (which should be only when camps are here)\n        let itemN (length a) - 1 ; to identify the latest item\n        set a replace-item itemN a tempSublist\n        \n        print a
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

@#$#@#$#@
## PURPOSE

This model aims to explore the quantity of shellfish discarded at coastal and non-coastal locations to test the idea that we can confidently use the archaeological record to evaluate the importance of shellfish in prehistoric people’s diets. It is a variant of the Projectile point submodel added to the PaleoscapeABM.

## PROCESS OBVERVIEW AND SCHEDULING

### About the PaleoscapeABM (edited from PaleoscapeABM v4.2 ODD)

Each time step represents one day (Figure S1). At the beginning of the day, cells and camps are updated. Coastal cells follow a 15-day tidal cycle. In the last 5 days of this cycle, their return rates are updated to reflect Spring tide resource availability (even if they have been harvested during the previous 10 days). The camps keep a one-week log of collected caloric returns. When that return is lower than a set threshold, they use a decision-making algorithm to choose a new cell to move by the end of the day. If the selected cell is within range they move to it, if it is beyond their range, they move 75% of a day’s walk in the direction of that cell. 

Gatherers then begin a loop where they make mobility and gathering decisions with the time they have left in their day. During each iteration of the loop, foragers estimate the time required to walk directly to their assigned camp. If their time left is greater, they make a mobility decision designed to maximize their daily caloric return. After moving to a cell, they subtract their travel time. If the cell is an inland terrestrial cell, they harvest 20% of the resources of that cell, reflecting a linear 100m transect with 10m visible on either side, and subtract the time expended in harvesting that resource. If the cell is coastal, they harvest 33% of the resources reflecting our experimental results demonstrating that three people can completely harvest a 100m strip of coastline in one pass. We assume that gatherers are able to observe a previous gatherer’s transect and thus, the return rate of each cell remains constant until it is completely depleted. If their travel time to camp is less than or equal to their time left, they move one cell towards their camp and do not harvest resources. Gatherers repeat this loop until they run out of foraging time. 

### Coastal variant addition

When gatherers collect marine shellfish, they first evaluate where their camp is. If the camp is further than the onsiteProcessThreshold, they process the shellfish where they collected it. In the model, this means that the patch where they stand add the kcal of the collected shellfish to their total-kcal-shell-process list. If the camp is closer than the threshold, gatherers collect the shellfish and process them at camp at the end of the day; the patch under the camp adds the collected kcal of shellfish to their total-kcal-shell list. At the end of the day, each camp records the kcal of collected plants and hunted animals of its people.

## Initialization

At setup, the patches take on the vegetation value given by the PaleoscapeABM, which is based on GIS maps of the region’s vegetation. A certain number of camps are created at random on the landscape, in which a given number of foragers are created. A certain % of those foragers are set as hunters, each of which is given a projectile armature used to hunt. 

Each patch creates empty lists that will record the kcal of food processed on them, as well as the number of projectile points discarded on them, when applicable. The simulation creates a csv file, in which variables of patches with discarded armatures are recorded at the end of the simulation. The file takes on the patch ID (xy values), a value that indicates if this is a camp site or a coastal processing site, the vegetation type of the patch, the number of armatures discarded on it, and all the food discard lists.

## SUBMODELS

The submodels detailed here are the ones that relate directly to the Coastal variant or are parts of the PaleoscapeABM procedures that were either changed for this variant, or that directly relate to it. For the complete PaleoscapeABM procedures, see its ODD protocol.

### Camp movement

At the beginning of each day, camps evaluate if their people have collected more food within the last week (on average) than a set threshold. If they are short, they choose one new cell to move to and move to it.

When camps move to a new cell, that new cell records this by adding +1 to its site? counter. It also records the vegetation from which the camp come from in its previous-vt list variable.

### Plant and shellfish gathering

All gatherers first calculate how long it would take them to walk back to their camp. If that value is lower than the time left in the day, they select a cell to gather food from, walk to it, and gather resources. If they do not have much time left, they walk to the current location of their camp.

When they gather, foragers take on 10% of each non-coastal cell’s resources at each pass, and 30% of each coastal resource. When collecting coastal resources (shellfish), they calculate how far their camp is. If that distance is farther than a set threshold, they process the shellfish where they stand. Therefore, the cell where they stand collects the kcal value of the collected shellfish. This is to mimic the goal of minimizing mobility cost as complete shellfish can be heavy and costly to transport over long distance. If the camp is closer, the agent collects shellfish until it needs to walk back to camp (we assume that the agents have bags in which they can store the shells while on the move) where they process them. When processing shellfish at the camp, the shells are deposited on the cell where the camp stands, thus creating a proxy archaeological record.

At the end of the day when all gatherers are back to their camp, the camp tells the cell it is on to update its list of food discard: this value is the sum of all kcal collected by all its people during the day, grouped by food type (plant, meat, and shellfish). Here, we assume that all the food gathered is consumed on the same day, and therefore, that their archaeological traces are discarded where the camp is. This should be improved on for future models, to allow transport of some unconsumed resources if the camp moves the following day.

### Hunting

All hunters first calculate how long it would take them to walk back to their camp. If they do not have much time left, they walk to the current location of their camp. If they still have some time to hunt, they face a cell with the highest hunting return and walk to it. The chance of animal encounter is based on weighted probabilities informed by surveys. If hunters encounter an animal, they calculate the cost of pursuing it taking into account the probability of success. Those probabilities are set from the start and are based on ethnographic observations. 

When a hunter decides to pursue the prey, it chooses its weapon with a probability set on the Interface. If the weapon is a projectile one, it throws it at the animal. Probabilities based on ethnography inform if the throw is successful or not. When a throw misses, the weapon has a certain probability of hitting trees, scrub, or the ground, based on the vegetation and values calculated by Fischer 1984. When a weapon breaks this way, it is discarded on the cell where the hunt took place. 

When a throw I successful, probabilities based on experiments inform where the weapon hit the prey (Schoville et al. 2010; Schoville and Otárola-Castillo 2014). This in turn affects if the weapon incurs damage or is embedded into the animal. Embedded weapons that are not broken can get reused based on a probability set by the user. Broken weapons that are not embedded are discarded on the spot. If the weapon is embedded in a part of the animal that gets transported back to camp (which varies based on the animal size), the weapon gets transported along it and gets discarded on the cell where the camp stands.

## RELATED MODELS

**PaleoscapeABM:**

Colin Wren (2016, December 29). “An agent-based approach to weighted decision making in the spatially and temporally variable South African Paleoscape” (Version 1.0.0). CoMSES Computational Model Library. Retrieved from: https://doi.org/10.25937/r2qq-fn02

**PaleoscapeABM with projectile discard:**

Claudine Gravel-Miguel (2021, March 23). “Armature distribution within the PaleoscapeABM” (Version 1.0.0). CoMSES Computational Model Library. Retrieved from: https://www.comses.net/codebases/9ba3f739-4da6-4212-8c1c-20b3dedba31b/releases/1.0.0/


## CREDITS AND REFERENCES

Fischer, A., Hansen, P.V., Rasmussen, P., 1984. Macro and Micro Wear Traces on Lithic Projectile Points: Experimental Results and Prehistoric Examples. Journal of Danish Archaeology. 3, 19–46.

Schoville, B.J., Brown, K.S., Otárola-Castillo, E., 2010. Modeling Middle Stone Age Lithic Discard Due to Impact Fractures Using Experimental Data from a Calibrated Crossbow, Pinnacle Point, South Africa. Presented at the Annual Meeting of the Paleoanthropology Society, St. Louis, MO.

Schoville, B.J., Otárola-Castillo, E., 2014. A model of hunter-gatherer skeletal element transport: the effect of prey body size, carriers, and distance. J Hum Evol. 73, 1–14.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="QI_Sensitivity_Length" repetitions="1" runMetricsEveryStep="true">
    <setup>reset-timer
setup
set file "Coastal_HPC_Sensitivity_Length.csv"</setup>
    <go>go</go>
    <metric>export-values-HPC</metric>
    <enumeratedValueSet variable="camp-move-threshold">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-tick">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nrcamps">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spatial-foresight">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="map-zone">
      <value value="&quot;z2&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-time-budget">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time_interval">
      <value value="365"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hunter-percent">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vision-forager">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-movement">
      <value value="&quot;local-patch-choice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount_rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_kcal_to_harvest">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nrforagers">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="days_of_foresight">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="global-knowledge?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-mode">
      <value value="&quot;kcal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="recoverytime">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outputs?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mobility">
      <value value="&quot;gatherer-driven&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="walk-speed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="point-recycling">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="point-hunting-rate">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QI_Sensitivity_Repetitions" repetitions="500" runMetricsEveryStep="false">
    <setup>reset-timer
setup
set file "Coastal_HPC_Sensitivity_Repetitions.csv"</setup>
    <go>go</go>
    <metric>export-values-HPC</metric>
    <enumeratedValueSet variable="camp-move-threshold">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-tick">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nrcamps">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spatial-foresight">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="map-zone">
      <value value="&quot;z2&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-time-budget">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time_interval">
      <value value="365"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hunter-percent">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vision-forager">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-movement">
      <value value="&quot;local-patch-choice&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount_rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_kcal_to_harvest">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nrforagers">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="days_of_foresight">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="global-knowledge?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-mode">
      <value value="&quot;kcal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="recoverytime">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outputs?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mobility">
      <value value="&quot;gatherer-driven&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="walk-speed">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="point-recycling">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="point-hunting-rate">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QI_Sensitivity_Settings" repetitions="5" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>reset-timer
setup
set file "Coastal_HPC_Sensitivity_Settings.csv"</setup>
    <go>go</go>
    <metric>export-values-HPC</metric>
    <enumeratedValueSet variable="camp-move-threshold">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-tick">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nrcamps">
      <value value="5"/>
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spatial-foresight">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="map-zone">
      <value value="&quot;z2&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-time-budget">
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time_interval">
      <value value="365"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hunter-percent">
      <value value="0.3"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vision-forager">
      <value value="10"/>
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-movement">
      <value value="&quot;local-patch-choice&quot;"/>
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount_rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_kcal_to_harvest">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nrforagers">
      <value value="40"/>
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="days_of_foresight">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="global-knowledge?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-mode">
      <value value="&quot;kcal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="recoverytime">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outputs?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mobility">
      <value value="&quot;gatherer-driven&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="walk-speed">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="point-recycling">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="point-hunting-rate">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="onsiteProcessThreshold">
      <value value="10"/>
      <value value="30"/>
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="QI_Main" repetitions="50" runMetricsEveryStep="false">
    <setup>reset-timer
setup
set file "Coastal_HPC_Main.csv"</setup>
    <go>go</go>
    <metric>export-values-HPC</metric>
    <enumeratedValueSet variable="camp-move-threshold">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-tick">
      <value value="365"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nrcamps">
      <value value="5"/>
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spatial-foresight">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="map-zone">
      <value value="&quot;z2&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-time-budget">
      <value value="10"/>
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time_interval">
      <value value="365"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="plots?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hunter-percent">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="vision-forager">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="forager-movement">
      <value value="&quot;local-patch-choice&quot;"/>
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="discount_rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max_kcal_to_harvest">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nrforagers">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="days_of_foresight">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="global-knowledge?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-mode">
      <value value="&quot;kcal&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="recoverytime">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="outputs?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mobility">
      <value value="&quot;gatherer-driven&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="walk-speed">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="point-recycling">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="point-hunting-rate">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="onsiteProcessThreshold">
      <value value="20"/>
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
